emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[elpa] externals/org 74df6e55c2: Merge branch 'bugfix'


From: ELPA Syncer
Subject: [elpa] externals/org 74df6e55c2: Merge branch 'bugfix'
Date: Thu, 1 Dec 2022 17:58:08 -0500 (EST)

branch: externals/org
commit 74df6e55c23d5aeb0911b294e60253a084d7116f
Merge: d500b406fc d122c2b5b4
Author: Kyle Meyer <kyle@kyleam.com>
Commit: Kyle Meyer <kyle@kyleam.com>

    Merge branch 'bugfix'
---
 doc/org-manual.org    |  8 ++++----
 etc/ORG-NEWS          | 22 +++++++++++-----------
 lisp/ob-clojure.el    |  4 ++--
 lisp/ob-tangle.el     |  6 +++---
 lisp/ol.el            |  2 +-
 lisp/org-agenda.el    |  2 +-
 lisp/org-attach.el    |  2 +-
 lisp/org-capture.el   |  2 +-
 lisp/org-clock.el     |  7 +++++--
 lisp/org-compat.el    | 12 ++++++------
 lisp/org-cycle.el     |  2 +-
 lisp/org-element.el   | 24 ++++++++++++------------
 lisp/org-fold-core.el | 40 ++++++++++++++++++++--------------------
 lisp/org-macs.el      |  2 +-
 lisp/org-persist.el   |  2 +-
 lisp/org.el           | 20 ++++++++++----------
 lisp/ox-icalendar.el  |  2 +-
 lisp/ox-latex.el      | 10 +++++-----
 lisp/ox-md.el         |  3 ++-
 19 files changed, 88 insertions(+), 84 deletions(-)

diff --git a/doc/org-manual.org b/doc/org-manual.org
index 67b8b4deef..63e9d4139f 100644
--- a/doc/org-manual.org
+++ b/doc/org-manual.org
@@ -13722,7 +13722,7 @@ A sample Org file with the above headers:
 #+vindex: org-export-default-language
 LaTeX packages =babel= or =polyglossia= can also be loaded in a
 document.  The "AUTO" string will be replaced in both cases by the
-appropiate value for the =LANGUAGE= keyword, if present in the
+appropriate value for the =LANGUAGE= keyword, if present in the
 document, or by the value of ~org-export-default-language~.  Let's see
 some examples in one or another case.
 
@@ -18491,7 +18491,7 @@ options; they are mutually exclusive.
 
   Ignore the results completely.  This option is similar to =none=,
   but no processing is performed on the return value.  Calling the
-  code block programatically (see [[*How to evaluate source code]]) or by
+  code block programmatically (see [[*How to evaluate source code]]) or by
   reference (see [[*Passing arguments]] and [[*Noweb Reference Syntax]]) will
   always yield nil.
 
@@ -18784,7 +18784,7 @@ a octal shorthand is defined, =oXXX= (=o= for octal). 
Using this, our
 read-only example is =:tangle-mode o444=. Omitting the =o= prefix will
 cause the argument to be interpreted as an integer, which can lead to
 unexpected results (=444= is the same as =o674=).
-Two other shorthands are recognised, ls-style strings like
+Two other shorthands are recognized, ls-style strings like
 =rw-r--r--=, and chmod-style permissions like =g+w=.
 Note that chmod-style permissions are based on
 ~org-babel-tangle-default-file-mode~, which is =#o544= by default.
@@ -18792,7 +18792,7 @@ Note that chmod-style permissions are based on
 When =:tangle-mode= and =:shebang= are both specified, the give
 =:tangle-mode= will override the permissions from =:shebang=. When
 multiple source code blocks tangle to a single file with conflicting
-=:tangle-mode= header arguments, Org's behaviour is undefined.
+=:tangle-mode= header arguments, Org's behavior is undefined.
 
 #+cindex: @samp{no-expand}, header argument
 By default Org expands code blocks during tangling.  The =no-expand=
diff --git a/etc/ORG-NEWS b/etc/ORG-NEWS
index d01fc804a0..5d5e726e00 100644
--- a/etc/ORG-NEWS
+++ b/etc/ORG-NEWS
@@ -56,7 +56,7 @@ The old folding backend used in Org is poorly scalable when 
the file
 size increases beyond few Mbs.  The symptoms usually include slow
 cursor motion, especially in long-running Emacs sessions.
 
-A new optimised folding backend is now available, and enabled by
+A new optimized folding backend is now available, and enabled by
 default.  To disable it, put the following to the Emacs config *before*
 loading Org:
 
@@ -64,14 +64,14 @@ loading Org:
 (setq org-fold-core-style 'overlays)
 #+end_src
 
-Even more performance optimisation can be enabled by customising
+Even more performance optimization can be enabled by customizing
 =org-fold-core--optimise-for-huge-buffers=.  However, this option may
 be dangerous.  Please, read the variable docstring carefully to
 understand the possible consequences.
 
 When =org-fold-core-style= is set to =text-properties=, several new
 features will become available and several notable changes will happen
-to the Org behaviour.  The new features and changes are listed below.
+to the Org behavior.  The new features and changes are listed below.
 
 **** Hidden parts of the links can now be searched and revealed during isearch
 
@@ -79,7 +79,7 @@ In the past, hidden parts of the links could not be searched 
using
 isearch (=C-s=).  Now, they are searchable by default.  The hidden
 match is also revealed temporarily during isearch.
 
-To restore the old behaviour add the following core to your Emacs
+To restore the old behavior add the following core to your Emacs
 config:
 
 #+begin_src emacs-lisp
@@ -131,13 +131,13 @@ Now, it is not the case anymore.  The drawer folding 
state is
 preserved.  The initial folding state of all the drawers in buffer is
 set according to the startup visibility settings.
 
-To restore the old behaviour, add the following code to Emacs config:
+To restore the old behavior, add the following code to Emacs config:
 
 #+begin_src emacs-lisp
 (add-hook 'org-cycle-hook #'org-cycle-hide-drawers)
 #+end_src
 
-Note that old behaviour may cause performance issues when cycling
+Note that old behavior may cause performance issues when cycling
 headline visibility in large buffers.
 
 **** =outline-*= functions may no longer work correctly in Org mode
@@ -339,7 +339,7 @@ This is done by adding =#+ATTR_LATEX: :mode tabbing= at the 
top
 of the table.
 The default column width is set to 1/n times the latex textwidth,
 where n is the number of columns.
-This behaviour can be changed by supplying a =:align= parameter.
+This behavior can be changed by supplying a =:align= parameter.
 
 The tabbing environment can be useful when generating simple tables which
 can be span multiple pages and when table cells are allowed to overflow.
@@ -528,7 +528,7 @@ Diagnostic information about execution speed can be 
provided according
 to ~org-element--cache-map-statistics~ and
 ~org-element--cache-map-statistics-threshold~.
 
-~org-scan-tags~ and tag views in agenda utilise the new function.
+~org-scan-tags~ and tag views in agenda utilize the new function.
 *** New function ~org-element-at-point-no-context~
 
 This function is like ~org-element-at-point~, but it does not try to
@@ -553,10 +553,10 @@ argument.
 This function is intended for us in the definition of a ~kbd~ macro in
 files that are exported to Texinfo.
 
-*** =org-at-heading-p= now recognises optional argument. Its meaning is 
inverted.
+*** =org-at-heading-p= now recognizes optional argument. Its meaning is 
inverted.
 
 =org-at-heading-p= now returns t by default on headings inside folds.
-Passing optional argument will produce the old behaviour.
+Passing optional argument will produce the old behavior.
 
 *** =org-babel-execute:plantuml= can output ASCII graphs in the buffer
 
@@ -680,7 +680,7 @@ a function (called with the same arguments as
 
 An example of a such function for =info:= links is
 ~org-info-description-as-command~.  To access a manual section outside
-of Org, description may be pasted to shell prompt or evaluated withing
+of Org, description may be pasted to shell prompt or evaluated within
 Emacs using =M-:= (wrapped into parenthesis).  For example,
 description of the =info:org#Tags= link is =info "(org) Tags"=.  To
 restore earlier behavior add to your Emacs init file the following:
diff --git a/lisp/ob-clojure.el b/lisp/ob-clojure.el
index 6f1425a842..b424cf48ff 100644
--- a/lisp/ob-clojure.el
+++ b/lisp/ob-clojure.el
@@ -101,13 +101,13 @@
 
 (defcustom ob-clojure-babashka-command (executable-find "bb")
   "Path to the babashka executable."
-  :type 'file
+  :type '(choice file (const nil))
   :group 'org-babel
   :package-version '(Org . "9.6"))
 
 (defcustom ob-clojure-nbb-command (executable-find "nbb")
   "Path to the nbb executable."
-  :type 'file
+  :type '(choice file (const nil))
   :group 'org-babel
   :package-version '(Org . "9.6"))
 
diff --git a/lisp/ob-tangle.el b/lisp/ob-tangle.el
index e86f4e5286..bd17bda32b 100644
--- a/lisp/ob-tangle.el
+++ b/lisp/ob-tangle.el
@@ -339,7 +339,7 @@ matching a regular expression."
 
 (defun org-babel-interpret-file-mode (mode)
   "Determine the integer representation of a file MODE specification.
-The following forms are currently recognised:
+The following forms are currently recognized:
 - an integer (returned without modification)
 - \"o755\" (chmod style octal)
 - \"rwxrw-r--\" (ls style specification)
@@ -354,7 +354,7 @@ The following forms are currently recognised:
       (user-error "%1$o is not a valid file mode octal. \
 Did you give the decimal value %1$d by mistake?" mode)))
    ((not (stringp mode))
-    (error "File mode %S not recognised as a valid format." mode))
+    (error "File mode %S not recognized as a valid format." mode))
    ((string-match-p "^o0?[0-7][0-7][0-7]$" mode)
     (string-to-number (replace-regexp-in-string "^o" "" mode) 8))
    ((string-match-p 
"^[ugoa]*\\(?:[+-=][rwxXstugo]*\\)+\\(,[ugoa]*\\(?:[+-=][rwxXstugo]*\\)+\\)*$" 
mode)
@@ -365,7 +365,7 @@ Did you give the decimal value %1$d by mistake?" mode)))
                                             ",g=" (substring mode 3 6)
                                             ",o=" (substring mode 6 9))
                                    0))
-   (t (error "File mode %S not recognised as a valid format. See 
`org-babel-interpret-file-mode'." mode))))
+   (t (error "File mode %S not recognized as a valid format. See 
`org-babel-interpret-file-mode'." mode))))
 
 (defun org-babel-tangle-clean ()
   "Remove comments inserted by `org-babel-tangle'.
diff --git a/lisp/ol.el b/lisp/ol.el
index 0b4457b003..cd52e9cf4d 100644
--- a/lisp/ol.el
+++ b/lisp/ol.el
@@ -150,7 +150,7 @@ link.
   called with two arguments: the link location (a string such as
   \"~/foobar\", \"id:some-org-id\" or \"https://www.foo.com\";)
   and the description generated by `org-insert-link'.  It should
-  return the description to use (this reflects the behaviour of
+  return the description to use (this reflects the behavior of
   `org-link-make-description-function').  If it returns nil, no
   default description is used, but no error is thrown (from the
   user's perspective, this is equivalent to a default description
diff --git a/lisp/org-agenda.el b/lisp/org-agenda.el
index aecfc3d81c..eda2489384 100644
--- a/lisp/org-agenda.el
+++ b/lisp/org-agenda.el
@@ -5943,7 +5943,7 @@ displayed in agenda view."
     (goto-char (point-min))
     (while (re-search-forward regexp nil t)
       (catch :skip
-        ;; We do not run `org-agenda-skip' righ away because every single sexp
+        ;; We do not run `org-agenda-skip' right away because every single sexp
         ;; in the buffer is matched here, unlike day-specific search
         ;; in ordinary timestamps.  Most of the sexps will not match
         ;; the agenda day and it is quicker to run `org-agenda-skip' only for
diff --git a/lisp/org-attach.el b/lisp/org-attach.el
index f85811dc7f..41f3a568c0 100644
--- a/lisp/org-attach.el
+++ b/lisp/org-attach.el
@@ -524,7 +524,7 @@ DIR-property exists (that is different from the unset one)."
   "Attach URL."
   (interactive "MURL of the file to attach: \n")
   (let ((org-attach-method 'url)
-        (org-safe-remote-resources ; Assume saftey if in an interactive 
session.
+        (org-safe-remote-resources ; Assume safety if in an interactive 
session.
          (if noninteractive org-safe-remote-resources '(""))))
     (org-attach-attach url)))
 
diff --git a/lisp/org-capture.el b/lisp/org-capture.el
index df401d6a6c..b26afeb036 100644
--- a/lisp/org-capture.el
+++ b/lisp/org-capture.el
@@ -757,7 +757,7 @@ of the day at point (if any) or the current HH:MM time."
      (_ "* Invalid capture template"))))
 
 (defun org-capture--run-template-functions (keyword &optional local)
-  "Run funcitons associated with KEYWORD on template's plist.
+  "Run functions associated with KEYWORD on template's plist.
 For valid values of KEYWORD see `org-capture-templates'.
 If LOCAL is non-nil use the buffer-local value of `org-capture-plist'."
   ;; Used in place of `run-hooks' because these functions have no associated 
symbol.
diff --git a/lisp/org-clock.el b/lisp/org-clock.el
index 2758aeed40..f28805d5e6 100644
--- a/lisp/org-clock.el
+++ b/lisp/org-clock.el
@@ -1198,8 +1198,11 @@ If `only-dangling-p' is non-nil, only ask to resolve 
dangling
   (string-to-number (shell-command-to-string "ioreg -c IOHIDSystem | perl -ane 
'if (/Idle/) {$idle=(pop @F)/1000000000; print $idle; last}'")))
 
 (defvar org-x11idle-exists-p
-  ;; Check that x11idle exists
-  (and (eq 0 (call-process-shell-command
+  ;; Check that x11idle exists.  But don't do that on DOS/Windows,
+  ;; since the command definitely does NOT exist there, and invoking
+  ;; COMMAND.COM on MS-Windows is a bad idea -- it hangs.
+  (and (null (memq system-type '(windows-nt ms-dos)))
+       (eq 0 (call-process-shell-command
               (format "command -v %s" org-clock-x11idle-program-name)))
        ;; Check that x11idle can retrieve the idle time
        ;; FIXME: Why "..-shell-command" rather than just `call-process'?
diff --git a/lisp/org-compat.el b/lisp/org-compat.el
index 2f29754f1b..483f8844c3 100644
--- a/lisp/org-compat.el
+++ b/lisp/org-compat.el
@@ -1543,7 +1543,7 @@ key."
   "Run `org-fold-region' when in org-mode."
   (if (derived-mode-p 'org-mode)
       (org-fold-region (max from (point-min)) (min to (point-max)) flag 
'headline)
-    ;; Apply EXTRA to avoid breakages if adviced function definition
+    ;; Apply EXTRA to avoid breakages if advised function definition
     ;; changes.
     (apply oldfun from to flag extra)))
 
@@ -1551,7 +1551,7 @@ key."
   "Run `org-next-visible-heading' when in org-mode."
   (if (derived-mode-p 'org-mode)
       (org-next-visible-heading arg)
-    ;; Apply EXTRA to avoid breakages if adviced function definition
+    ;; Apply EXTRA to avoid breakages if advised function definition
     ;; changes.
     (apply oldfun arg extra)))
 
@@ -1571,7 +1571,7 @@ key."
                                   (point)))))
              (goto-char found)
              found)))
-    ;; Apply EXTRA to avoid breakages if adviced function definition
+    ;; Apply EXTRA to avoid breakages if advised function definition
     ;; changes.
     (apply oldfun invisible-ok extra)))
 
@@ -1579,7 +1579,7 @@ key."
   "Run `org-at-heading-p' when in org-mode."
   (if (derived-mode-p 'org-mode)
       (org-at-heading-p (not invisible-ok))
-    ;; Apply EXTRA to avoid breakages if adviced function definition
+    ;; Apply EXTRA to avoid breakages if advised function definition
     ;; changes.
     (apply oldfun invisible-ok extra)))
 
@@ -1587,7 +1587,7 @@ key."
   "Run `org-fold-hide-sublevels' when in org-mode."
   (if (derived-mode-p 'org-mode)
       (org-fold-hide-sublevels levels)
-    ;; Apply EXTRA to avoid breakages if adviced function definition
+    ;; Apply EXTRA to avoid breakages if advised function definition
     ;; changes.
     (apply oldfun levels extra)))
 
@@ -1600,7 +1600,7 @@ key."
             (org-fold-hide-subtree)
           (org-fold-show-children)
           (org-fold-show-entry 'hide-drawers)))
-    ;; Apply EXTRA to avoid breakages if adviced function definition
+    ;; Apply EXTRA to avoid breakages if advised function definition
     ;; changes.
     (apply oldfun extra)))
 
diff --git a/lisp/org-cycle.el b/lisp/org-cycle.el
index c06af06d95..9531ac4c8c 100644
--- a/lisp/org-cycle.el
+++ b/lisp/org-cycle.el
@@ -87,7 +87,7 @@
 (defvar-local org-cycle-subtree-status nil)
 (put 'org-cycle-subtree-status 'org-state t)
 
-;;;; Customisation:
+;;;; Customization:
 
 
 (defgroup org-cycle nil
diff --git a/lisp/org-macs.el b/lisp/org-macs.el
index 9188999007..0c6a2173d2 100644
--- a/lisp/org-macs.el
+++ b/lisp/org-macs.el
@@ -1082,7 +1082,7 @@ Return width in pixels when PIXELS is non-nil."
         (setq-local buffer-invisibility-spec
                     (if (listp current-invisibility-spec)
                         (mapcar (lambda (el)
-                                  ;; Consider elipsis to have 0 width.
+                                  ;; Consider ellipsis to have 0 width.
                                   ;; It is what Emacs 28+ does, but we have
                                   ;; to force it in earlier Emacs versions.
                                   (if (and (consp el) (cdr el))
diff --git a/lisp/org-persist.el b/lisp/org-persist.el
index d60fdc657a..108292f1e9 100644
--- a/lisp/org-persist.el
+++ b/lisp/org-persist.el
@@ -189,7 +189,7 @@
 (defcustom org-persist-remote-files 100
   "Whether to keep persistent data for remote files.
 
-When this variable is nil, never save persitent data associated with
+When this variable is nil, never save persistent data associated with
 remote files.  When t, always keep the data.  When
 `check-existence', contact remote server containing the file and only
 keep the data when the file exists on the server.  When a number, keep
diff --git a/lisp/org.el b/lisp/org.el
index a05a282293..ab6212dacc 100644
--- a/lisp/org.el
+++ b/lisp/org.el
@@ -1383,13 +1383,13 @@ For more examples, see the system specific constants
 (defcustom org-resource-download-policy 'prompt
   "The policy applied to requests to obtain remote resources.
 
-This affects keywords like #+setupfile and #+incude on export,
+This affects keywords like #+setupfile and #+include on export,
 `org-persist-write:url',and `org-attach-url' in non-interactive
 Emacs sessions.
 
-This recognises four possible values:
+This recognizes four possible values:
 - t, remote resources should always be downloaded.
-- prompt, you will be prompted to download resources nt considered safe.
+- prompt, you will be prompted to download resources not considered safe.
 - safe, only resources considered safe will be downloaded.
 - nil, never download remote resources.
 
@@ -1408,7 +1408,7 @@ URI regexps are applied to both URLs and Org files 
requesting
 remote resources."
   :group 'org
   :package-version '(Org . "9.6")
-  :type '(list regexp))
+  :type '(repeat regexp))
 
 (defcustom org-open-non-existing-files nil
   "Non-nil means `org-open-file' opens non-existing files.
@@ -4625,7 +4625,7 @@ returns non-nil if any of them match."
                 ", which is not considered safe.\n\n"
                 "Do you want to download this?  You can type\n "
                 (propertize "!" 'face 'success)
-                " to download this resource, and permanantly mark it as 
safe.\n "
+                " to download this resource, and permanently mark it as 
safe.\n "
                 (if domain
                     (concat
                      (propertize "d" 'face 'success)
@@ -4636,7 +4636,7 @@ returns non-nil if any of them match."
                 (propertize "f" 'face 'success)
                 (if current-file
                     (concat
-                     " to download this resource, and permanantly mark all 
resources in "
+                     " to download this resource, and permanently mark all 
resources in "
                      (propertize current-file 'face 'underline)
                      " as safe.\n ")
                   "")
@@ -4764,7 +4764,7 @@ This is for getting out of special buffers like capture.")
 (defvar org-element-cache-persistent); Defined in org-element.el
 (defvar org-element-use-cache); Defined in org-element.el
 (defvar org-mode-loading nil
-  "Non-nil during Org mode initialisation.")
+  "Non-nil during Org mode initialization.")
 
 (defvar org-agenda-file-menu-enabled t
   "When non-nil, refresh Agenda files in Org menu when loading Org.")
@@ -5270,7 +5270,7 @@ This includes angle, plain, and bracket links."
                (progn
                   (add-face-text-property start end face-property)
                  (add-text-properties start end properties))
-              ;; Initialise folding when used outside org-mode.
+              ;; Initialize folding when used outside org-mode.
               (unless (or (derived-mode-p 'org-mode)
                          (and (org-fold-folding-spec-p 'org-link-description)
                                (org-fold-folding-spec-p 'org-link)))
@@ -5287,7 +5287,7 @@ This includes angle, plain, and bracket links."
                   (org-fold-core-set-folding-spec-property spec :visible t))
                 (org-fold-region start end nil 'org-link)
                 (org-fold-region start end nil 'org-link-description)
-                ;; We are folding the whole emphasised text with SPEC
+                ;; We are folding the whole emphasized text with SPEC
                 ;; first.  It makes everything invisible (or whatever
                 ;; the user wants).
                 (org-fold-region start end t spec)
@@ -6407,7 +6407,7 @@ Return nil before first heading."
                            "" h))
                          (h h)))
              (tags (and (not no-tags) (match-string 5))))
-          ;; Restore cleared optimisation.
+          ;; Restore cleared optimization.
           (org-fold-core-update-optimisation (match-beginning 0) (match-end 0))
          (mapconcat #'identity
                     (delq nil (list todo priority headline tags))
diff --git a/lisp/ox-icalendar.el b/lisp/ox-icalendar.el
index f4c904da4a..cfbfabafb0 100644
--- a/lisp/ox-icalendar.el
+++ b/lisp/ox-icalendar.el
@@ -75,7 +75,7 @@ for timed events.  If non-zero, alarms are created.
 (defcustom org-icalendar-force-alarm nil
   "Non-nil means alarm will be created even if is set to zero.
 
-This overrides default behaviour where zero means no alarm.  With
+This overrides default behavior where zero means no alarm.  With
 this set to non-nil and alarm set to zero, alarm will be created
 and will fire at the event start."
   :group 'org-export-icalendar
diff --git a/lisp/ox-latex.el b/lisp/ox-latex.el
index 46a348a68f..5b29a284c9 100644
--- a/lisp/ox-latex.el
+++ b/lisp/ox-latex.el
@@ -928,7 +928,7 @@ The function should return the string to be exported."
 (defcustom org-latex-src-block-backend 'verbatim
   "Backend used to generate source code listings.
 
-This sets the behaviour for fontifying source code, possibly even with
+This sets the behavior for fontifying source code, possibly even with
 color.  There are four implementations of this functionality you may
 choose from (ordered from least to most capable):
 1. Verbatim
@@ -942,7 +942,7 @@ highlighting (listings), or none at all (verbatim).
 When using listings, you also need to make use of LaTeX package
 \"listings\".  The \"color\" LaTeX package is also needed if you
 would like color too.  These can simply be added to
-`org-latex-packages-alist', using customise or something like:
+`org-latex-packages-alist', using customize or something like:
 
   (require \\='ox-latex)
   (add-to-list \\='org-latex-packages-alist \\='(\"\" \"listings\"))
@@ -981,7 +981,7 @@ Emacs' font-lock information.  This requires the Emacs 
package
 engrave-faces (available from ELPA), and the LaTeX package
 fvextra be installed.
 
-The styling of the engraved result can be customised with
+The styling of the engraved result can be customized with
 `org-latex-engraved-preamble' and `org-latex-engraved-options'.
 The default preamble also uses the LaTeX package tcolorbox in
 addition to fvextra."
@@ -1202,11 +1202,11 @@ as long as it:
   \"Verbatim\" environments (provided by fvextra) will be wrapped with.
 
 In the default value the colors \"EFD\" and \"EfD\" are provided
-as they are respectively the foreground and background colours,
+as they are respectively the foreground and background colors,
 just in case they aren't provided by the generated preamble, so
 we can assume they are always set.
 
-Within this preamble there are two recognised macro-like placeholders:
+Within this preamble there are two recognized macro-like placeholders:
 
   [FVEXTRA-SETUP]
 
diff --git a/lisp/ox-md.el b/lisp/ox-md.el
index dee6dbf1fc..dcd95e9871 100644
--- a/lisp/ox-md.el
+++ b/lisp/ox-md.el
@@ -87,7 +87,8 @@ included into another document or application that reserves 
top-level
 headings for its own use."
   :group 'org-export-md
   :package-version '(Org . "9.6")
-  :type 'string)
+  ;; Avoid `natnum' because that's not available until Emacs 28.1.
+  :type 'integer)
 
 
 



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/lisp/org-element.el b/lisp/org-element.el
index a290b4121f..48ede9c528 100644
--- a/lisp/org-element.el
+++ b/lisp/org-element.el
@@ -713,11 +713,11 @@ is cleared and contents are removed in the process."
            ;; DATUM is i.e. a headline, it's property list (`:title'
            ;; in case of headline) can contain parsed objects.  The
            ;; objects will contain `:parent' property set to the DATUM
-           ;; itself.  When copied, these inner `:parent' propery
+           ;; itself.  When copied, these inner `:parent' property
            ;; values will contain incorrect object decoupled from
            ;; DATUM.  Changes to the DATUM copy will not longer be
            ;; reflected in the `:parent' properties.  So, we need to
-           ;; reassign inner `:parent' propreties to the DATUM copy
+           ;; reassign inner `:parent' properties to the DATUM copy
            ;; explicitly.
            (org-element-map element-copy (cons 'plain-text 
org-element-all-objects)
              (lambda (obj) (when (equal datum (org-element-property :parent 
obj))
@@ -4780,7 +4780,7 @@ Elements are accumulated into ACC."
                            ;; elements.  Below code reassigns
                            ;; `:parent' property of the element and
                            ;; may interfere with cache
                            ;; synchronisation if parent element is not
                            ;; yet in cache.  Moreover, the returned
                            ;; structure may be altered by caller code
                            ;; arbitrarily.  Hence, we return a copy of
@@ -5434,14 +5434,14 @@ OFFSET and, if they belong to element PARENT, are 
adopted by it.
 
 PHASE specifies the phase number, as an integer.
 
-For any synchronisation request, all the later requests in the cache
+For any synchronization request, all the later requests in the cache
 must not start at or before END.  See `org-element--cache-submit-request'.")
 
 (defvar-local org-element--cache-sync-timer nil
   "Timer used for cache synchronization.")
 
 (defvar-local org-element--cache-sync-keys-value nil
-  "Id value used to identify keys during synchronisation.
+  "Id value used to identify keys during synchronization.
 See `org-element--cache-key' for more information.")
 
 (defvar-local org-element--cache-change-tic nil
@@ -5468,9 +5468,9 @@ See `org-element--cache-key' for more information.")
 This variable is used to determine when re-parsing buffer is not going
 to slow down the command.
 
-If the commends end up modifying the cache, the worst case scenario is
+If the commands end up modifying the cache, the worst case scenario is
 performance drop.  So, advicing these commands is safe.  Yet, it is
-better to remove the commands adviced in such way from this list.")
+better to remove the commands advised in such a way from this list.")
 
 (defmacro org-element--request-key (request)
   "Get NEXT part of a `org-element--cache-sync-requests' REQUEST."
@@ -6291,7 +6291,7 @@ completing the request."
                 (key (org-element--cache-key data)))
             ;; Traverse the cache tree.  Ignore all the elements before
             ;; START.  Note that `avl-tree-stack' would not bypass the
-            ;; elements before START and thus would have beeen less
+            ;; elements before START and thus would have been less
             ;; efficient.
            (if (and leftp (avl-tree--node-left node)
                     (not (org-element--cache-key-less-p key start)))
@@ -6793,7 +6793,7 @@ By default (when this variable is nil), cache re-parses 
modified
 headlines immediately after modification preserving all the unaffected
 elements inside the headline.
 
-The default behaviour works best when users types inside Org buffer of
+The default behavior works best when users types inside Org buffer of
 when buffer modifications are mixed with cache requests.  However,
 large automated edits inserting/deleting many headlines are somewhat
 slower by default (as in `org-archive-subtree').  Let-binding this
@@ -7383,7 +7383,7 @@ the cache."
     (save-excursion
       (save-restriction
         (unless narrow (widen))
-        ;; Synchronise cache up to the end of mapped region.
+        ;; Synchronize cache up to the end of mapped region.
         (org-element-at-point to-pos)
         (cl-macrolet ((cache-root
                         ;; Use the most optimal version of cache available.
@@ -7418,7 +7418,7 @@ the cache."
                         ;; point.
                         () `(progn
                               ;; Parsing is one of the performance
-                              ;; bottlenecks.  Make sure to optimise it as
+                              ;; bottlenecks.  Make sure to optimize it as
                               ;; much as possible.
                               ;;
                               ;; Avoid extra staff like timer cancels et al
@@ -7737,7 +7737,7 @@ the cache."
                       ;; longer trust STACK.
                       (cache-walk-restart)))
                   ;; Second, move to the right branch of the tree or skip
-                  ;; it alltogether.
+                  ;; it altogether.
                   (if continue-flag
                      (setq continue-flag nil)
                    (setq node (if (and (car stack)
@@ -4780,7 +4780,7 @@ Elements are accumulated into ACC."
                            ;; `:parent' property of the element and
                            ;; may interfere with cache
-                           ;; synchronisation if parent element is not
+                           ;; synchronization if parent element is not
                            ;; yet in cache.  Moreover, the returned
                            ;; structure may be altered by caller code
diff --git a/lisp/org-fold-core.el b/lisp/org-fold-core.el
index 692c51a74c..be600f8a0c 100644
--- a/lisp/org-fold-core.el
+++ b/lisp/org-fold-core.el
@@ -78,7 +78,7 @@
 
 ;; Similar to 'org-fold-visible, display of any arbitrary folding spec
 ;; can be configured using folding spec properties.  In particular,
-;; `:visible' folding spec proprety controls whether the folded text
+;; `:visible' folding spec property controls whether the folded text
 ;; is visible or not.  If the `:visible' folding spec property is nil,
 ;; folded text is hidden or displayed as a constant string (ellipsis)
 ;; according to the value of `:ellipsis' folding spec property.  See
@@ -91,7 +91,7 @@
 ;; If necessary, one can add or remove folding specs using
 ;; `org-fold-core-add-folding-spec' and `org-fold-core-remove-folding-spec'.
 
-;; If a buffer initialised with `org-fold-core-initialize' is cloned into 
indirect
+;; If a buffer initialized with `org-fold-core-initialize' is cloned into 
indirect
 ;; buffers, it's folding state is copied to that indirect buffer.
 ;; The folding states are independent.
 
@@ -148,7 +148,7 @@
 ;; same spec can be used for fold different syntaxical structures.
 ;; Any folding spec can be additionally referenced by a symbol listed
 ;; in the spec's `:alias' folding spec property.  For example, Org
-;; mode's `org-fold-outline' folding spec can be referened as any
+;; mode's `org-fold-outline' folding spec can be referenced as any
 ;; symbol from the following list: '(headline heading outline
 ;; inlinetask plain-list) The list is the value of the spec's `:alias'
 ;; property.
@@ -170,7 +170,7 @@
 ;; possible to control to unfold it temporarily during interactive
 ;; isearch session.
 
-;; The isearch behaviour is controlled on per-folding-spec basis by
+;; The isearch behavior is controlled on per-folding-spec basis by
 ;; setting `isearch-open' and `isearch-ignore' folding spec
 ;; properties.  The the docstring of `org-fold-core--specs' for more details.
 
@@ -179,12 +179,12 @@
 ;; The visibility of the text inserted in front, rear, or in the
 ;; middle of a folded region is managed according to `:front-sticky'
 ;; and `:rear-sticky' folding properties of the corresponding folding
-;; spec.  The rules are the same with stickyness of text properties in
+;; spec.  The rules are the same with stickiness of text properties in
 ;; Elisp.
 
 ;; If a text being inserted into the buffer is already folded and
-;; invisible (before applying the stickyness rules), then it is
-;; revealed.  This behaviour can be changed by wrapping the insertion
+;; invisible (before applying the stickiness rules), then it is
+;; revealed.  This behavior can be changed by wrapping the insertion
 ;; code into `org-fold-core-ignore-modifications' macro.  The macro will 
disable
 ;; all the processing related to buffer modifications.
 
@@ -233,13 +233,13 @@
 ;; visible part of a buffer may cause noticeable lags (which is still
 ;; orders of magnitude better in comparison with overlays).  If the
 ;; performance issues become critical while using this library, it is
-;; recommended to minimise the number of folding specs used in the
+;; recommended to minimize the number of folding specs used in the
 ;; same buffer at a time.
 
 ;; Alternatively, the library provides 
`org-fold-core--optimise-for-huge-buffers'
 ;; for additional speedup.  This can be used as a file-local variable
 ;; in huge buffers.  The variable can be set to enable various levels
 ;; of extra optimisation.  See the docstring for detailed information.
 
 ;; It is worth noting that when using 
`org-fold-core--optimise-for-huge-buffers'
 ;; with `grab-invisible' option, folded regions copied to other
@@ -250,7 +250,7 @@
 
 ;; Another possible bottleneck is the fragility check after the change
 ;; related to the folded text.  The functions used in `:fragile'
-;; folding properties must be optimised.  Also,
+;; folding properties must be optimized.  Also,
 ;; `org-fold-core-ignore-fragility-checks' or even 
`org-fold-core-ignore-modifications' may be
 ;; used when appropriate in the performance-critical code.  When
 ;; inserting text from within `org-fold-core-ignore-modifications' macro, it is
@@ -302,7 +302,7 @@ be revealed.")
 (defvar-local org-fold-core--optimise-for-huge-buffers nil
   "Non-nil turns on extra speedup on huge buffers (Mbs of folded text).
 
-This setting is risky and may cause various artefacts and degraded
+This setting is risky and may cause various artifacts and degraded
 functionality, especially when using external packages.  It is
 recommended to enable it on per-buffer basis as file-local variable.
 
@@ -337,7 +337,7 @@ following symbols:
   used.
 
 - `merge-folds': Do not distinguish between different types of folding
-  specs.  This is the most aggressive optimisation with unforeseen and
+  specs.  This is the most aggressive optimization with unforeseen and
   potentially drastic effects.")
 (put 'org-fold-core--optimise-for-huge-buffers 'safe-local-variable 'listp)
 
@@ -355,7 +355,7 @@ following symbols:
   "Folding specs defined in current buffer.
 
 Each spec is a list (SPEC-SYMBOL SPEC-PROPERTIES).
-SPEC-SYMBOL is the symbol respresenting the folding spec.
+SPEC-SYMBOL is the symbol representing the folding spec.
 SPEC-PROPERTIES is an alist defining folding spec properties.
 
 If a text region is folded using multiple specs, only the folding spec
@@ -600,7 +600,7 @@ unless RETURN-ONLY is non-nil."
                                                  
(org-fold-core-folding-spec-list)))
                                    (remove (assq 'invisible 
char-property-alias-alist)
                                            char-property-alias-alist)))
-                  ;; Set folding property stickyness according to
+                  ;; Set folding property stickiness according to
                   ;; their `:font-sticky' and `:rear-sticky'
                   ;; parameters.
                   (let (full-prop-list)
@@ -1185,7 +1185,7 @@ instead of text properties.  The created overlays will be 
stored in
            ;; We do not want it here.
            (with-silent-modifications
               (org-fold-core-region (car region) (cdr region) nil spec)
-             ;; The overlay is modelled after `outline-flag-region'
+             ;; The overlay is modeled after `outline-flag-region'
              ;; [2020-05-09 Sat] overlay for 'outline blocks.
              (let ((o (make-overlay (car region) (cdr region) nil 
'front-advance)))
                (overlay-put o 'evaporate t)
@@ -1303,7 +1303,7 @@ property, unfold the region if the :fragile function 
returns non-nil."
               (unless (org-fold-core-region-folded-p from to spec)
                (let ((spec-to (org-fold-core-get-folding-spec spec (min to (1- 
(point-max)))))
                      (spec-from (org-fold-core-get-folding-spec spec (max 
(point-min) (1- from)))))
-                  ;; Reveal folds around undoed deletion.
+                  ;; Reveal folds around undone deletion.
                   (when undo-in-progress
                     (let ((lregion (org-fold-core-get-region-at-point spec 
(max (point-min) (1- from))))
                           (rregion (org-fold-core-get-region-at-point spec 
(min to (1- (point-max))))))
@@ -1412,7 +1412,7 @@ property, unfold the region if the :fragile function 
returns non-nil."
 ;; To avoid the above situation, we simply clear all the properties,
 ;; unrealated to current buffer when a text is copied.
 ;; FIXME: Ideally, we may want to carry the folding state of copied
-;; text between buffer (probably via user customisation).
+;; text between buffer (probably via user customization).
 (defun org-fold-core--buffer-substring-filter (beg end &optional delete)
   "Clear folding state in killed text.
 This function is intended to be used as `filter-buffer-substring-function'.
@@ -1421,7 +1421,7 @@ The arguments and return value are as specified for 
`filter-buffer-substring'."
        ;; The list will be used as an argument to `remove-text-properties'.
        props-list)
     ;; There is no easy way to examine all the text properties of a
-    ;; string, so we utilise the fact that printed string
+    ;; string, so we utilize the fact that printed string
     ;; representation lists all its properties.
     ;; Loop over the elements of string representation.
     (unless (or (string= "" return-string)
@@ -1481,7 +1481,7 @@ The arguments and return value are as specified for 
`filter-buffer-substring'."
     return-string))
 
 (defun org-fold-core-update-optimisation (beg end)
-  "Update huge buffer optimisation between BEG and END.
+  "Update huge buffer optimization between BEG and END.
 See `org-fold-core--optimise-for-huge-buffers'."
   (when (and (memql 'grab-invisible org-fold-core--optimise-for-huge-buffers)
              (eq org-fold-core-style 'text-properties))
@@ -1494,7 +1494,7 @@ See `org-fold-core--optimise-for-huge-buffers'."
         (setq pos (org-fold-core-next-folding-state-change (caar 
org-fold-core--specs) pos end))))))
 
 (defun org-fold-core-remove-optimisation (beg end)
-  "Remove huge buffer optimisation between BEG and END.
+  "Remove huge buffer optimization between BEG and END.
 See `org-fold-core--optimise-for-huge-buffers'."
   (when (and (memql 'grab-invisible org-fold-core--optimise-for-huge-buffers)
              (eq org-fold-core-style 'text-properties))
@@ -233,13 +233,13 @@
 ;; for additional speedup.  This can be used as a file-local variable
 ;; in huge buffers.  The variable can be set to enable various levels
-;; of extra optimisation.  See the docstring for detailed information.
+;; of extra optimization.  See the docstring for detailed information.
 
 ;; It is worth noting that when using 